errors

package
v0.0.0-...-768bde1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2016 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fail

func Fail(err error, msg string)

Fail logs the error and exits the program Only use this to handle critical errors

func Log

func Log(err error, msg string)

Log only logs the error but doesn't exit the program Use this to log errors that should not exit the program

Types

This section is empty.

Jump to