Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TaskArg ¶
type TaskArg struct {
Type string
Value interface{}
}
TaskArg represents a single argument passed to invocation fo a task
type TaskHeaders ¶
type TaskHeaders map[string]interface{}
TaskHeaders represents the headers which should be used to direct the task
type TaskSignature ¶
type TaskSignature struct {
UUID string
Name string
RoutingKey string
GroupUUID string
GroupTaskCount int
Args []TaskArg
Headers TaskHeaders
Immutable bool
OnSuccess []*TaskSignature
OnError []*TaskSignature
ChordCallback *TaskSignature
}
TaskSignature represents a single task invocation
func (*TaskSignature) AdjustRoutingKey ¶
func (taskSignature *TaskSignature) AdjustRoutingKey(exchangeType, bindingKey, queueName string)
AdjustRoutingKey makes sure the routing key is correct. If the routing key is an empty string: a) set it to binding key for direct exchange type b) set it to default queue name
Click to show internal directories.
Click to hide internal directories.